Spyder - Documentation
======================

Spyder is the Scientific PYthon Development EnviRonment:

* a powerful interactive development environment for the Python language with 
  advanced editing, interactive testing, debugging and introspection features
  
* and a numerical computing environment thanks to the support of `IPython` 
  (enhanced interactive Python interpreter) and popular Python libraries 
  such as `NumPy` (linear algebra), `SciPy` (signal and image processing) 
  or `matplotlib` (interactive 2D/3D plotting).

Spyder may also be used as a library providing powerful console-related widgets 
for your PyQt-based applications -- for example, it may be used to integrate a 
debugging console directly in the layout of your graphical user interface.

Spyder websites:

* Downloads, bug reports and feature requests: https://github.com/spyder-ide/spyder
* Discussions: http://groups.google.com/group/spyderlib
            

Contents:

.. toctree::
    :maxdepth: 2
    :glob:
    
    overview
    installation
    options
    editor
    ipythonconsole
    debugging
    console
    variableexplorer
    help
    projects
    pylint
    fileexplorer
    historylog
    findinfiles
    onlinehelp
    internalconsole

Indices and tables:

* :ref:`genindex`
* :ref:`search`
